@@ -1,14 +1,10 @@
-//! # `rasn-mib`: Management Information Base
-//! This crate represents an implementation of MIB objects defined in IETF RFCs,
-//! Nearly all of these types are newtype wrappers around their network
-//! protocol type, and as such don't they add any additional overhead in terms
-//! of size, any `OBJECT-TYPE` information is available statically through the
-//! [`smi::ObjectType`] trait.
-
+#![doc = include_str!("../README.md")]
 #![no_std]
 
 extern crate alloc;
 
+pub mod address_family_numbers;
+
 use alloc::{vec, vec::Vec};
 
 use rasn::types::*;
@@ -247,7 +243,7 @@ pub mod interfaces {
         type Error = rasn::ber::enc::Error;
 
         fn try_from(value: Entry) -> Result<Self, Self::Error> {
-            value.into_opaque()
+            value.to_opaque()
         }
     }
 
@@ -293,7 +289,7 @@ pub mod interfaces {
             encoder: &mut EN,
             tag: Tag,
         ) -> Result<(), EN::Error> {
-            self.into_opaque()
+            self.to_opaque()
                 .map_err(rasn::enc::Error::custom)?
                 .encode_with_tag(encoder, tag)
         }
